@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
- *  Copyright (C) 2004,2005 Crispin Flowerday
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
+ *  Copyright © 2004,2005 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sidebar-extension.c,v 1.15 2006/05/16 22:25:41 wbolster Exp $
+ *  $Id: ephy-sidebar-extension.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
 #include "config.h"
@@ -127,7 +127,7 @@ ephy_sidebar_extension_get_type (void)
 GType
 ephy_sidebar_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphySidebarExtensionClass),
 		NULL, /* base_init */
@@ -140,7 +140,7 @@ ephy_sidebar_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_sidebar_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_sidebar_extension_iface_init,
 		NULL,
