@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-states-extension.c,v 1.6 2005/04/28 20:21:48 chpe Exp $
+ *  $Id: ephy-tab-states-extension.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
 #include "config.h"
@@ -67,7 +67,7 @@ ephy_tab_states_extension_get_type (void)
 GType
 ephy_tab_states_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyTabStatesExtensionClass),
 		NULL, /* base_init */
@@ -80,7 +80,7 @@ ephy_tab_states_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_tab_states_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_tab_states_extension_iface_init,
 		NULL,
